Crate repl_lib

Crate repl_lib 

Structs

Line
Represents a single line of input with cursor position.
Repl
Interactive Read-Eval-Print Loop implementation.
UserError

Enums

Error
Repl error.
InternalError
Error type for REPL operations.

Type Aliases

LineCompletionFunc
Function type for determining if a line is complete.
ProcessLineFunc
Function type for processing input lines.
Result
Result type alias for repl_lib operations.