Structs
- Line
- Represents a single line of input with cursor position.
- Repl
- Interactive Read-Eval-Print Loop implementation.
Enums
- Error
- Error type for REPL operations.
Type Aliases
- Line
Completion Func - Function type for determining if a line is complete.
- Process
Line Func - Function type for processing input lines.
- Result
- Result type alias for repl_lib operations.